Library used to interact with storage backend and IPFS (to store encrypted snapshots and manage metadata).
Re-exports
pub use crate::keys::Hash;pub use crate::keys::Privkey;pub use crate::keys::Pubkey;pub use crate::keys::Secret;pub use crate::stream::*;
Modules
Structs
- Header
Stream - Taking a bytes stream, decode the header, and pass through the other data unchanged.
- Manifest
- Manifest for snapshot.
- Manifest
Signed - Signed manifest, keeps raw encoded data, decoded manifest, and raw signature.
- Parent
- Snapshot
Header - Snapshot
Info - Volume
Edit - Volume
Info
Enums
Constants
Functions
- fetch_
decrypt - Fetch a snapshot from IPFS, decrypt it on-the-fly with the volume’s decryption key.
- health_
check - Health check.
- snapshot_
fetch - Upload a new snapshot
- snapshot_
list - Fetch latest (as in, most current generation) based on the parent generation that is passed.
- snapshot_
upload - Upload a new snapshot
- upload_
encrypt - Upload a stream of data to IPFS, encrypted with the volume’s encryption key.
- volume_
create - Create new snapshot repository, given a private key.
- volume_
edit - Edit a volume’s properties.
- volume_
get - Get volume’s info.
- volume_
remove - Remove volume.