pub struct VolumeEdit {
pub writer: Field<Uuid>,
pub account: Option<Uuid>,
pub lock: Option<bool>,
}Fields
writer: Field<Uuid>Which plugin UUID is allowed to write snapshots for this volume.
When missing, it doesn’t change anything. When None, it removes the
write field, meaning that anyone can write to it. When a UUID, that is the
new exclusive writer.
account: Option<Uuid>When set, transfers ownership of this volume to another account.
lock: Option<bool>Set this volume locked, this prevents pushing of new snapshots.